@@ -1384,13 +1384,24 @@ class OpenEVSE:
 
     # Safety counts
     @property
-    def checks_count(self) -> dict | None:
+    def checks_count(self) -> dict:
         """Return the saftey checks counts."""
         attributes = ("gfcicount", "nogndcount", "stuckcount")
+        counts = {}
         if self._status is not None and set(attributes).issubset(self._status.keys()):
-            counts = {}
             counts["gfcicount"] = self._status["gfcicount"]
             counts["nogndcount"] = self._status["nogndcount"]
             counts["stuckcount"] = self._status["stuckcount"]
-            return counts
-        return None
+        return counts
+
+    @property
+    async def async_override_state(self) -> str | None:
+        """Return the unit override state."""
+        try:
+            override = await self.get_override()
+        except UnsupportedFeature:
+            _LOGGER.debug("Override state unavailable on older firmware.")
+            return None
+        if "state" in override.keys():
+            return override["state"]
+        return "auto"
